@@ -1,5 +1,6 @@
-"""Tests for timeline related calendar eents."""
+"""Tests for timeline related calendar events."""
 
+from collections.abc import Generator
 import json
 
 import pytest
@@ -8,6 +9,29 @@ from pytest_golden.plugin import GoldenTestFixture
 from ical.calendar_stream import CalendarStream, IcsCalendarStream
 
 
+def test_empty_ics(mock_prodid: Generator[None, None, None]) -> None:
+    """Test serialization of an empty ics file."""
+    calendar = IcsCalendarStream.calendar_from_ics("")
+    ics = IcsCalendarStream.calendar_to_ics(calendar)
+    assert (
+        ics
+        == """BEGIN:VCALENDAR
+PRODID:-//example//1.2.3
+VERSION:2.0
+END:VCALENDAR"""
+    )
+
+    calendar.prodid = "-//example//1.2.4"
+    ics = IcsCalendarStream.calendar_to_ics(calendar)
+    assert (
+        ics
+        == """BEGIN:VCALENDAR
+PRODID:-//example//1.2.4
+VERSION:2.0
+END:VCALENDAR"""
+    )
+
+
 @pytest.mark.golden_test("testdata/*.yaml")
 def test_parse(golden: GoldenTestFixture, json_encoder: json.JSONEncoder) -> None:
     """Fixture to read golden file and compare to golden output."""
